@@ -5,26 +5,29 @@
 
 #include "channellogger.h"
 
+#include <QProcess>
+
 #include <KLocalizedString>
 #include <KNotification>
 
 #include <KTextToHTML>
 
-#include <qofonomessage.h>
-
 #include <global.h>
 #include <database.h>
 #include <phonenumberutils.h>
 
-ChannelLogger::ChannelLogger(QObject *parent)
+ChannelLogger::ChannelLogger(std::optional<QString> &modemPath, QObject *parent)
     : QObject(parent)
 {
-    // Set up sms account
-    m_msgManager.setModemPath(m_manager.defaultModem());
+    if (modemPath.has_value()) {
+        m_msgManager.setModemPath(*modemPath);
+    } else {
+        connect(&m_manager, &QOfonoManager::defaultModemChanged, this, [&] {
+            m_msgManager.setModemPath(m_manager.defaultModem());
+        });
 
-    connect(&m_manager, &QOfonoManager::defaultModemChanged, this, [&] {
         m_msgManager.setModemPath(m_manager.defaultModem());
-    });
+    }
 
     connect(&m_msgManager, &QOfonoMessageManager::incomingMessage, this, &ChannelLogger::handleIncomingMessage);
 }
@@ -36,7 +39,7 @@ void ChannelLogger::handleIncomingMessage(const QString &text, const QVariantMap
     message.sentByMe = false; // SMS doesn't have any kind of synchronization, so received messages are always from the chat partner.
     message.datetime = QDateTime::fromString(info[SL("SentTime")].toString().split(QChar(u'+'))[0], Qt::ISODate);
     message.deliveryStatus =  MessageState::Received; // It arrived, soo
-    message.phoneNumber = PhoneNumberUtils::normalize(info[SL("Sender")].toString());
+    message.phoneNumber = phoneNumberUtils::normalizeNumber(info[SL("Sender")].toString());
     message.id = Database::generateRandomId();
     message.read = false;
 
