@@ -9,6 +9,8 @@
 
 #include <qofonomanager.h>
 
+#include <optional>
+
 #include "messagemanager.h"
 
 class AsyncDatabase;
@@ -18,7 +20,7 @@ class ChannelHandler : public QObject
     Q_OBJECT
 
 public:
-    explicit ChannelHandler(QObject *parent = nullptr);
+    explicit ChannelHandler(std::optional<QString> &modemPath, QObject *parent = nullptr);
 
     AsyncDatabase &database();
     MessageManager &msgManager();
